MIRA VALENCIA : Abre en Valencia una escuela referente musical asociada a la universidad RockSchool británica

Tu plan |
V7-Show |
Fotos de Valencia |
Publicidad |
Quienes Somos |
Archivo
04 diciembre 2015
volver

# Abre en Valencia una escuela referente musical asociada a la universidad RockSchool británica

30/09/2015

##

Rock School Valencia abre sus puertas el 1 de octubre como centro asociado a la prestigiosa universidad RockSchool británica. La nueva escuela de música está llamada a ser un referente en la educación musical de Valencia. Los alumnos de Rock School Valencia obtienen una titulación homologada a nivel europeo reconocido en el plan Bolonia y en el Marco Europeo de Cualificaciones. Esta acreditación ayuda a todo aquel que quiere profesionalizar sus estudios o completarlos en universidades europeas.

Rock School es una organización examinadora en el Reino Unido que valida y reconoce los estudios de música moderna y sonido profesional con equivalencia en EDF mediante el proceso de Bolonia concediendo una titulación europea. Rock School Valencia,como centro oficial en España, cuenta con titulaciones que abarcan desde exámenes de música por grados hasta diplomas de enseñanza.

Situada en el número 70 de Blasco Ibañez junto a la avenida de Aragón, en plena zona universitaria, apuesta por una enseñanza musical e instrumental mediante cursos diseñados para todo tipo de estudiantes y edades, incluyendo niños, jóvenes y adultos, desde principiantes hasta aquellos que desean adquirir un alto nivel musical. Ofrece una educación de calidad con un amplio abanico de clases como guitarra eléctrica, guitarra clásica, piano, bajo eléctrico, batería, teclado moderno, técnica vocal, saxo, trombón, miedo escénico, armonía aplicada, escuela infantil, lenguaje musical, laboratorio de percusión o tratamiento de sonido para directo.

La asignatura de Rock Band permitirá a los alumnos poder aprender y disfrutar con otros músicos adquiriendo la experiencia necesaria para poder tocar en una banda de rock, pop, blues, soul, funk o reggae.

Rock School Valencia está dirigida por el músico Miguel de Tienda, guitarrista de conocidas formaciones de Rock, Reggae, Funk y Soul ( Mediterranean Roots y Elhombreviento en la actualidad). Cuenta con un reconocido profesorado formado por grandes artistas en el ámbito profesional y con años de experiencia dentro de la enseñanza musical. Cristobal Galán, Adrián Perales del grupo de metal In Mute, Rober Molina, David Barberá, Pablo Barrios, David Cases, Alfie Copovi , Jonás Sanchez o Vicente Grau forman este talentoso profesorado. Belén Balada, conocida publicitaria, responsable de marketing y comunicación, completa un equipo de alto nivel.

La escuela dispone de seis amplias aulas totalmente equipadas y un auditorio para llevar a cabo masterclases y seminarios de los mejores instrumentistas del mundo

Rock School Valencia refuerza su apuesta en una educación musical moderna al ser centro vinculado a la Escuela Superior de Música Jam Session, autorizada por el Departament d´Énsenyament de la Generalitat de Catalunya, que ofrece la titulación superior de música moderna en las especialidades de Interpretación, Pedagogía y Sonología, en el ámbito del Rock, Músicas Urbanas y Nuevas Tendencias.

Lejos quedan aquellos días donde la música rock solo se podía aprender de forma autodidacta, y la única vía de formación universitaria era a través de los estudios de música clásica o jazz. En Rock School Valencia aprender tu instrumento favorito divirtiéndote mientras obtienes una titulación de rock profesional es por fin una realidad.

Tweet
Comentarios:

Si quieres hacer un comentario a la noticia puedes realizarlo rellenando el siguiente formulario:
Comentario: |
Nombre: |
Email: |
| Copie el código Sensible a mayúsculas y minúsculas
NOTA: La inserción del comentario no es inmediata, tendremos que validarlo para ver si cumple las normas del portal.

MÁS NOTICIAS
FÚTBOL
El Valencia CF remonta con casta y gana en Lasesarre al Barakaldo
03/12/2015 0 comentarios
TEATRO
Les Arts acoge el ensayo general de Macbeth con Plácido Domingo como protagonista
03/12/2015 0 comentarios
TRADICIÓN
Villancicos en valenciano esta Navidad
03/12/2015 0 comentarios
TEATRO
Cultura efervescente y desbordante para empezar el año en Sala Russafa
03/12/2015 0 comentarios
TRANSPORTE
Simulacro de incendio de madrugada entre las estaciones de Metro Salt de l`Aigua y Quart de Poblet
03/12/2015 0 comentarios
ANIMALES
Los niños y las niñas de La Fe han explorado e investigado la fauna y flora africana con sus propias manos
03/12/2015 0 comentarios
GASTRONOMÍA
Los platos de varios países muestran la multiculturalidad del Campus de Gandia
03/12/2015 0 comentarios
COMERCIO
Mª Elisa Sánchez es la ganadora de un crucero del aniversario del Supermercado de El Corte Inglés
03/12/2015 0 comentarios
SOCIEDAD
La Gran Noche de las Compras valencianas llena los comercios de degustaciones, espectáculos y regalos
03/12/2015 0 comentarios
Aviso Legal | Contacto